API Documentation
=================

The ``nukeuuid`` API is very simple and consists of two main functions,
a UUID setter and a node getter.

.. autofunction:: nukeuuid.set_uuid()

.. autofunction:: nukeuuid.get_nodes()
